Learn R Programming

RRMLRfMC (version 0.4.0)

derivatives: derivatives

Description

This function is used calculate the derivative values (first and second derivatives for Newton-Raphson method) and loglikelihood when updating A

Usage

derivatives(A, Gamma, Dmat, I, zy, refA)

Arguments

A

matrix with value from previous iteration

Gamma

G matrix values

Dmat

the coefficient matrix for the fixed variables,

I

a U by U incidence matrix with elements; I(i,j)=1 if state j can be accessed from state i in one step and 0 otherwise

zy

the variable values for a given observation

refA

a vector of reference categories

Value

a list of outputs:

  • fird: the first derivative value

  • secd: the second derivative value

  • loglike: the loglikelihood